hpp_functions = '''
#ifndef __mg_functions_h__
#define __mg_functions_h__

#include <map>
#include <vector>
#include <cmath>
#include <string>
#include <algorithm>

template <class K, class T, class P>
bool in_map(const K& element, const std::map<T, P>& map)
{
    return map.count(element) > 0;
}

template <class I, class T>
bool in_list(I item, const std::vector<T>& list)
{
    return std::find(list.begin(), list.end(), item) != list.end();
}

template <class T, class I>
void list_push(std::vector<T>& list, const I& t)
{
    list.push_back(t);
}

template <class T, class I>
void list_remove(std::vector<T>& list, const I& t)
{
    auto iter = std::find(list.begin(), list.end(), t);
    if(iter != list.end())
        list.erase(iter);
}

template <class T>
int list_size(const std::vector<T>& vector)
{
    return static_cast<int>(vector.size());
}

template <class T>
void list_clear(std::vector<T>& vector)
{
    vector.clear();
}

template <class T, class P>
int map_size(const std::map<T, P>& map)
{
    return static_cast<int>(map.size());
}

bool string_empty(const std::string& string);
int string_size(const std::string& string);

float random_float();
int random_int(int min, int max);

#endif
'''
cpp_functions = '''
#include "mg_extensions.h"
#include <cstdlib>

float random_float()
{
    return std::rand() / static_cast<float>(RAND_MAX);
}

int random_int(int min, int max)
{
    auto diff = max - min;
    if(diff > 0)
    {
        return std::rand() % diff + min;
    }
    return min;
}

bool string_empty(const std::string& string)
{
    return string.empty();
}

int string_size(const std::string& string)
{
    return static_cast<int>(string.size());
}


'''
